import unittest
from unittest.mock import patch, MagicMock
import sys
import os
import pandas as pd
import numpy as np

# 현재 파일의 디렉토리
current_dir = os.path.dirname(os.path.abspath(__file__))

# 상위 디렉토리를 sys.path에 추가
parent_dir = os.path.abspath(os.path.join(current_dir, '..', '..'))
if parent_dir not in sys.path:
    sys.path.insert(0, parent_dir)

from scripts.data_processing.live_data_processing import real_time_prediction

class RealTimePredictionTest(unittest.TestCase):

    @patch('scripts.data_processing.live_data_processing.get_real_time_data_with_retry')
    def test_real_time_prediction_with_insufficient_data(self, mock_get_data):
        # Mock insufficient data (less than 30 rows)
        mock_data = pd.DataFrame({
            'stck_prpr': np.random.rand(20)  # 20 rows of random data
        })
        mock_get_data.return_value = mock_data

        model = MagicMock()
        scaler = MagicMock()

        ticker = "FAKE_TICKER"
        time_step = 30

        predictions = real_time_prediction(model, scaler, ticker, time_step)
        self.assertIsNone(predictions)

    @patch('scripts.data_processing.live_data_processing.get_real_time_data_with_retry')
    def test_real_time_prediction_with_sufficient_data(self, mock_get_data):
        # Mock sufficient data (more than 30 rows)
        mock_data = pd.DataFrame({
            'stck_prpr': np.random.rand(50)  # 50 rows of random data
        })
        mock_get_data.return_value = mock_data

        model = MagicMock()
        model.predict.return_value = np.random.rand(20, 1)  # Mock prediction output
        scaler = MagicMock()
        scaler.inverse_transform.return_value = np.random.rand(20, 1)  # Mock inverse transform

        ticker = "FAKE_TICKER"
        time_step = 30

        predictions = real_time_prediction(model, scaler, ticker, time_step)
        self.assertIsNotNone(predictions)
        self.assertEqual(predictions.shape[0], 20)

if __name__ == '__main__':
    unittest.main()
